%define anolis_release 1

%bcond_without check

%global gnupg2_min_ver 2.2.24
%global libgpg_error_min_ver 1.36

Name:           gpgme
Summary:        GnuPG Made Easy - high level crypto API
Version:        1.20.0
Release:        %{anolis_release}%{?dist}

# MIT: src/cJSON.{c,h} (used by gpgme-json)
License:        LGPLv2+ and MIT
URL:            https://gnupg.org/related_software/gpgme/
Source0:        https://gnupg.org/ftp/gcrypt/gpgme/gpgme-%{version}.tar.bz2

## downstream patches
# Don't add extra libs/cflags in gpgme-config/cmake equivalent
Patch1001:      0001-don-t-add-extra-libraries-for-linking.patch
# add -D_FILE_OFFSET_BITS... to gpgme-config, upstreamable
Patch1002:      gpgme-1.3.2-largefile.patch
# Let's fix stupid AX_PYTHON_DEVEL
Patch1003:      0001-fix-stupid-ax_python_devel.patch
# Allow extra options to be passed to setup.py during installation
Patch1004:      0002-setup_py_extra_opts.patch
 
## temporary downstream fixes
# Skip lang/qt/tests/t-remarks on gnupg 2.4+
Patch3001:      1001-qt-skip-test-remarks-for-gnupg2-2.4.patch

BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  python3-distutils-extra
BuildRequires:  gcc-c++
BuildRequires:  gawk
BuildRequires:  gnupg2 >= %{gnupg2_min_ver}
BuildRequires:  gnupg2-smime
BuildRequires:  libgpg-error-devel >= %{libgpg_error_min_ver}
BuildRequires:  libassuan-devel >= 2.4.2

BuildRequires:  swig

BuildRequires:  chrpath

BuildRequires:  cmake

Requires:       gnupg2 >= %{gnupg2_min_ver}

%description
GnuPG Made Easy (GPGME) is a library designed to make access to GnuPG
easier for applications. It provides a high-level crypto API for
encryption, decryption, signing, signature verification and key
management. Currently it uses GnuPG's OpenPGP backend as the default,
but the API isn't restricted to this engine. We have, in fact, already
developed a backend for CMS (S/MIME).

%package doc
Summary:	Doc files for %{name}
Requires:	%{name} = %{version}-%{release}
BuildArch:	noarch

%description doc
Doc files for %{name}

%package devel
Summary:        Development headers and libraries for %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains the development headers and libraries for %{name}.

%package -n %{name}pp
Summary:        C++ bindings/wrapper for GPGME
Obsoletes:      gpgme-pp < 1.8.0-7
Provides:       gpgme-pp = %{version}-%{release}
Requires:       %{name} = %{version}-%{release}

%description -n %{name}pp
This package contains the C++ bindings/wrapper for %{name}.

%package -n %{name}pp-devel
Summary:        Development libraries and header files for %{name}-pp
Obsoletes:      gpgme-pp-devel < 1.8.0-7
Provides:       gpgme-pp-devel = %{version}-%{release}
Requires:       %{name}pp = %{version}-%{release}
Requires:       %{name}-devel = %{version}-%{release}

%description -n %{name}pp-devel
This package contains the development libraries and header files for %{name}-pp.

%package -n q%{name}
Summary:        Qt API bindings/wrapper for GPGME
Requires:       %{name}pp = %{version}-%{release}
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)

%description -n q%{name}
This package contains the Qt API bindings/wrapper for %{name}.

%package -n q%{name}-devel
Summary:        Development libraries and header files for %{name}
Conflicts:      kdepimlibs-devel < 4.14.10-17
Requires:       q%{name} = %{version}-%{release}
Requires:       %{name}pp-devel
BuildRequires:  cmake

%description -n q%{name}-devel
This package contains the development libraries and header files for %{name}.

%package -n python3-gpg
Summary:        %{name} bindings for Python 3
%{?python_provide:%python_provide python3-gpg}
BuildRequires:  python3-devel
Requires:       %{name} = %{version}-%{release}
Obsoletes:      platform-python-gpg < %{version}-%{release}

%description -n python3-gpg
This package contains the %{name} bindings for Python 3.

%prep
%autosetup -p1

## HACK ALERT
# The config script already suppresses the -L if it's /usr/lib, so cheat and
# set it to a value which we know will be suppressed.
sed -i -e 's|^libdir=@libdir@$|libdir=@exec_prefix@/lib|g' src/gpgme-config.in

# The build machinery does not support Python 3.9+ yet
# https://github.com/gpg/gpgme/pull/4
sed -i 's/3.8/%{python3_version}/g' configure

%build
export CFLAGS='%{optflags} -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
export CXXFLAGS='%{optflags} -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
export CFLAGS="$(echo ${CFLAGS} | tr '\n\\' '  ')"
export CXXFLAGS="$(echo ${CXXFLAGS} | tr '\n\\' '  ')"

%configure --disable-static --disable-silent-rules --enable-languages=cpp,qt,python
%make_build

%install
# When using distutils from setuptools 60+, ./setup.py install use
# the .egg format. This forces setuptools to use .egg-info format.
# SETUP_PY_EXTRA_OPTS is introduced by the Patch1004 above.
export SETUPTOOLS_USE_DISTUTILS=local
export SETUP_PY_EXTRA_OPTS="--single-version-externally-managed --root=/"
%make_install

chrpath -d %{buildroot}%{_bindir}/%{name}-tool
chrpath -d %{buildroot}%{_bindir}/%{name}-json
chrpath -d %{buildroot}%{_libdir}/lib%{name}pp.so*
%if %{with qt}
chrpath -d %{buildroot}%{_libdir}/libq%{name}.so*
%endif

%generate_compatibility_deps

%if %{with check}
%check
%make_build check
%endif

%files
%license COPYING* LICENSES
%dir %{abidir}
%{_bindir}/%{name}-json
%{abidir}/%{name}-json-option.list
%{_libdir}/lib%{name}.so.11*
%{abidir}/lib%{name}.dump

%files doc
%doc AUTHORS NEWS README*

%files devel
%{_bindir}/%{name}-config
%{_bindir}/%{name}-tool
%{abidir}/%{name}-tool-option.list
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so
%{_datadir}/aclocal/%{name}.m4
%{_infodir}/%{name}.info*
%{_libdir}/pkgconfig/%{name}*.pc

%files -n %{name}pp
%doc lang/cpp/README
%{_libdir}/lib%{name}pp.so.6*
%{abidir}/lib%{name}pp.dump

%files -n %{name}pp-devel
%{_includedir}/%{name}++
%{_libdir}/lib%{name}pp.so
%{_libdir}/cmake/Gpgmepp

%files -n q%{name}
%doc lang/qt/README
%{_libdir}/libq%{name}.so.15*
%{abidir}/libq%{name}.dump

%files -n q%{name}-devel
%{_includedir}/q%{name}
%{_includedir}/QGpgME/
%{_libdir}/libq%{name}.so
%{_libdir}/cmake/QGpgme/

%files -n python3-gpg
%doc lang/python/README
%{python3_sitearch}/gpg-*.egg-info
%{python3_sitearch}/gpg/
%{abidir}/*%{name}*python*.dump

%changelog
* Fri Apr 21 2023 Funda Wang <fundawang@yeah.net> - 1.20.0-1
- New version 1.20.0

* Mon Apr 10 2023 Funda Wang <fundawang@yeah.net> - 1.19.0-2
- Fix build with latest distutils

* Mon Mar 20 2023 Funda Wang <fundawang@yeah.net> - 1.19.0-1
- New version 1.19.0

* Mon Mar 13 2023 Feng Su <sufeng@linux.alibaba.com> - 1.18.0-3
- Correct the location of the dump files

* Fri Feb 24 2023 Feng Su <sufeng@linux.alibaba.com> - 1.18.0-2
- Add api/abi files
- Skip 4 qt remarks test cases

* Tue Oct 11 2022 Funda Wang <fundawang@yeah.net> - 1.18.0-1
- New version 1.18.0
- Add patch from other distro for removal overlinking in gpgme-config

* Fri Mar 11 2022 liuzhilin <liuzhilin@uniontech.com> - 1.17.0-1
- Init for Anolis OS 23
- fix stupid-ax_python_devel
